@@ -16,8 +16,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import mock
 import os
+from unittest import mock
 
 from oslo_utils import uuidutils
 
